@@ -7,6 +7,22 @@ from pywapor.enhancers import lulc
 import numpy as np
 
 def default_vars(product_name, req_vars):
+    """Given a `product_name` and a list of requested variables, returns a dictionary
+    with metadata on which exact layers need to be requested from the server, how they should
+    be renamed, and how their dimensions are defined.
+
+    Parameters
+    ----------
+    product_name : str
+        Name of the product.
+    req_vars : list
+        List of variables to be collected.
+
+    Returns
+    -------
+    dict
+        Metadata on which exact layers need to be requested from the server.
+    """
     variables = {
         '2009_V2.3_Global': {
                 "Band1": [("lat", "lon"), "lulc"],
@@ -32,6 +48,22 @@ def remove_var(ds, var):
     return ds.drop_vars([var])
 
 def default_post_processors(product_name, req_vars):
+    """Given a `product_name` and a list of requested variables, returns a dictionary with a 
+    list of functions per variable that should be applied after having collected the data
+    from a server.
+
+    Parameters
+    ----------
+    product_name : str
+        Name of the product.
+    req_vars : list
+        List of variables to be collected.
+
+    Returns
+    -------
+    dict
+        Functions per variable that should be applied to the variable.
+    """
 
     post_processors = {
         '2009_V2.3_Global': {
@@ -52,11 +84,49 @@ def default_post_processors(product_name, req_vars):
     return out
 
 def url_func(product_name):
+    """Returns a url at which to collect GLOBCOVER data.
+
+    Parameters
+    ----------
+    product_name : None
+        Not used.
+
+    Returns
+    -------
+    str
+        The url.
+    """
     return r"http://due.esrin.esa.int/files/GLOBCOVER_L4_200901_200912_V2.3.color.tif"
 
 def download(folder, latlim, lonlim, product_name, req_vars = ["lulc"],
                 variables = None, post_processors = None, **kwargs):
-    
+    """Download GLOBCOVER data and store it in a single netCDF file.
+
+    Parameters
+    ----------
+    folder : str
+        Path to folder in which to store results.
+    latlim : list
+        Latitude limits of area of interest.
+    lonlim : list
+        Longitude limits of area of interest.
+    timelim : list
+        Period for which to prepare data.
+    product_name : str, optional
+        Name of the product to download, by default "P05".
+    req_vars : list, optional
+        Which variables to download for the selected product, by default ["p"].
+    variables : dict, optional
+        Metadata on which exact layers need to be requested from the server, by default None.
+    post_processors : dict, optional
+        Functions per variable that should be applied to the variable, by default None.
+
+    Returns
+    -------
+    xr.Dataset
+        Downloaded data.
+    """
+
     folder = os.path.join(folder, "GLOBCOVER")
 
     appending = False
